Similar projects
==========================================

from this list_:
 * kiwi_
         - PyGTK only
 * dogtail_
         - GUI test tool and automation framework
         - It uses Accessibility (a11y) technologies
         to communicate with desktop applications.
 * ldtp_
         - The GNU/Linux Desktop (GUI Application) Testing Project

.. _kiwi: http://www.async.com.br/projects/kiwi/
.. _dogtail: https://fedorahosted.org/dogtail/  
.. _ldtp: http://ldtp.freedesktop.org/wiki/
.. _list: http://pycheesecake.org/wiki/PythonTestingToolsTaxonomy#GUITestingTools



       